#!/usr/bin/env python
from argparse import ArgumentParser

from jamd import jamd_viewer


def parse_arguments():
    arguments = ArgumentParser()
    arguments.add_argument('path', help='Markdown file to be opened')

    return arguments.parse_args()


def main():
    arguments = parse_arguments()
    jamd_viewer.run(arguments.path)


if __name__ == '__main__':
    main()



from unittest import TestCase
from mock import patch, MagicMock

from jamd import jamd_viewer
from jamd import markdown_parser


class TestJamdViewer(TestCase):
    def setUp(self):
        self.markdown = patch('markdown.markdown').start()
        jamd_viewer.app.testing = True
        self.client = jamd_viewer.app.test_client()
        self.FlaskDesktopUI = patch('jamd.jamd_viewer.FlaskDesktopUI').start()

        self.flask_desktop_ui = MagicMock()
        self.FlaskDesktopUI.return_value = self.flask_desktop_ui

    def tearDown(self):
        patch.stopall()

    def test_it_parses_markdown_file_to_html(self):
        self.markdown.return_value = 'html_result'

        html = markdown_parser.to_html('something in markdown')

        self.markdown.assert_called_once_with('something in markdown', extensions=['extra'])
        assert html == 'html_result'

    def test_it_runs_flask_desktop_ui_serving_a_markdown_file(self):
        self.markdown.return_value = 'html_result'

        jamd_viewer.run('README.md')
        response = self.client.get('/')

        assert response.status_code == 200
        assert response.data == b'html_result'
        self.FlaskDesktopUI.assert_called_once_with(jamd_viewer.app)
        self.flask_desktop_ui.run.assert_called_once()



#!/usr/bin/env python
import os

from flask import Flask
from flask_desktop_ui import FlaskDesktopUI

from jamd import markdown_parser


app = Flask(__name__, static_url_path='')


def run(path):
    app.static_folder = os.path.dirname(os.path.abspath(path))
    markdown_contents = ''

    if os.path.exists(path):
        with open(path) as file:
            markdown_contents = file.read()

    @app.route('/')
    def markdown_in_html_endpoint():
        return markdown_parser.to_html(markdown_contents)

    FlaskDesktopUI(app).run()
